@@ -263,6 +263,9 @@ void TerminalDisplay::setVTFont(const QFont& f)
     // Disabling kerning saves some computation when rendering text. 
     font.setKerning(false);
 
+    // Konsole cannot handle non-integer font metrics
+    font.setStyleStrategy(QFont::StyleStrategy(font.styleStrategy() | QFont::ForceIntegerMetrics));
+
     QWidget::setFont(font);
     fontChange(font);
   }
